@@ -51,3 +51,8 @@ async def get_async_request_data(method, params):
   return response
 def get_async_response(method, params):
     return asyncio.run(get_async_request_data(method, params))
+
+
+def get_solcatcher_call(method, **kwargs):
+  return asyncio.run(asyncPostRequest(getEndpointUrl(method),data=kwargs))
+  
