@@ -13,7 +13,7 @@ async def async_getBlock(slot,encoding=None,maxSupportedTransactionVersion=None,
     params = await makeParams(int(slot), encoding=encoding,maxSupportedTransactionVersion=maxSupportedTransactionVersion,transactionDetails=transactionDetails,rewards=rewards)
     return await makeLimitedDbCall(method,  await combineParamDicts(params))
 
-def getBlock(slot,encoding=None,maxSupportedTransactionVersion=None,transactionDetails=None,rewards=None):
+def getBlock(slot, encoding=None,maxSupportedTransactionVersion=None,transactionDetails=None,rewards=None):
     return get_async_response(async_getBlock, slot, encoding=encoding,maxSupportedTransactionVersion=maxSupportedTransactionVersion,transactionDetails=transactionDetails,rewards=rewards)
 
 async def async_getLatestBlockHash(commitment=None):
@@ -129,3 +129,11 @@ async def async_getGenesisSignature(address):
 def getGenesisSignature(address):
     return get_async_response(async_getGenesisSignature, address)
 
+async def async_getParsedTransaction(tx_sig=None,txnData=None,,maxSupportedTransactionVersion=None):
+    maxSupportedTransactionVersion=maxSupportedTransactionVersion or 0
+    method = "getParsedTransaction"
+    params = await makeParams(tx_sig=tx_sig,txnData=txnData, maxSupportedTransactionVersion=maxSupportedTransactionVersion)
+    return await makeLimitedDbCall(method, params)
+
+def getParsedTransaction(tx_sig=None,txnData=None,maxSupportedTransactionVersion=None):
+    return get_async_response(tx_sig=tx_sig,txnData=txnData, maxSupportedTransactionVersion=maxSupportedTransactionVersion)
